@@ -125,7 +125,7 @@ class MapInterface:
         # Initialize Communication: ZMQ --------------------------------------------------------------------------------
         # --------------------------------------------------------------------------------------------------------------
 
-        if not self.__zmq_opts_sub_tpa and self.__bool_enable_interface2tpa:
+        if self.__zmq_opts_sub_tpa and self.__bool_enable_interface2tpa:
             self.zmq_context = zmq.Context()
 
             # Init ZMQ sockets for communication with tire performance assessment module
